@@ -17,9 +17,9 @@ except:
 	sys.exit(1)
 
 import hildon
-import osso
+#import osso
 import conic
-import dbus
+#import dbus
 
 from gnome import gconf
 import threading
